=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2011-01-29 23:08:49 +0000
+++ drizzled/error.cc	2011-01-31 16:31:35 +0000
@@ -580,7 +580,7 @@
   ADD_ERROR_MESSAGE(ER_CATALOG_NO_LOCK, N_("Could not gain lock on '%s'."));
   ADD_ERROR_MESSAGE(ER_CORRUPT_CATALOG_DEFINITION, N_("Corrupt or invalid catalog definition for '%s' : '%s'."));
   ADD_ERROR_MESSAGE(ER_WRONG_NAME_FOR_CATALOG, N_("Invalid catalog name."));
-
+  ADD_ERROR_MESSAGE(ER_USE_DATA_DICTIONARY, N_("Engine status is now stored in the data_dictionary tables, please use these instead."));
 
 }
 

=== modified file 'drizzled/error_t.h'
--- drizzled/error_t.h	2011-01-29 23:08:49 +0000
+++ drizzled/error_t.h	2011-01-31 16:31:35 +0000
@@ -864,10 +864,10 @@
   ER_INVALID_TIME_VALUE,
   ER_INVALID_DATE_VALUE,
   ER_TRANSACTIONAL_DDL_NOT_SUPPORTED,
-
+  ER_USE_DATA_DICTIONARY,
   // Leave ER_INVALID_BOOLEAN_VALUE as LAST, and force people to use tags
   // instead of numbers in error messages in test.
-  ER_ERROR_LAST=   ER_TRANSACTIONAL_DDL_NOT_SUPPORTED
+  ER_ERROR_LAST=   ER_USE_DATA_DICTIONARY
 };
 
 

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2011-01-25 07:18:43 +0000
+++ drizzled/show.cc	2011-01-31 16:31:35 +0000
@@ -305,6 +305,16 @@
   return true;
 }
 
+bool buildEngineStatus(Session *session, LEX_STRING)
+{
+  session->getLex()->sql_command= SQLCOM_SELECT;
+  drizzled::statement::Show *select= new statement::Show(session);
+  session->getLex()->statement= select;
+
+  my_error(ER_USE_DATA_DICTIONARY);
+  return false;
+}
+
 bool buildColumns(Session *session, const char *schema_ident, Table_ident *table_ident)
 {
   session->getLex()->sql_command= SQLCOM_SELECT;

=== modified file 'drizzled/show.h'
--- drizzled/show.h	2011-01-26 19:15:55 +0000
+++ drizzled/show.h	2011-01-31 16:31:35 +0000
@@ -66,6 +66,7 @@
 bool buildProcesslist(Session *session);
 bool buildScemas(Session *session);
 bool buildStatus(Session *session, const drizzled::sql_var_t is_global);
+bool buildEngineStatus(Session *session, LEX_STRING);
 bool buildTableStatus(Session *session, const char *ident);
 bool buildTables(Session *session, const char *ident);
 bool buildTemporaryTables(Session *session);

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-01-28 02:32:26 +0000
+++ drizzled/sql_yacc.yy	2011-01-31 16:31:35 +0000
@@ -4591,6 +4591,11 @@
             if (not show::buildStatus(YYSession, $1))
               DRIZZLE_YYABORT;
           }
+        | engine_option_value STATUS_SYM
+          {
+            if (not show::buildEngineStatus(YYSession, $1))
+              DRIZZLE_YYABORT;
+          }
         | CREATE TABLE_SYM table_ident
           {
             if (not show::buildCreateTable(YYSession, $3))

=== modified file 'm4/pandora_visibility.m4'
--- m4/pandora_visibility.m4	2011-01-30 09:39:58 +0000
+++ m4/pandora_visibility.m4	2011-01-31 17:31:13 +0000
@@ -23,7 +23,6 @@
 AC_DEFUN([PANDORA_CHECK_VISIBILITY],
 [
   AC_REQUIRE([AC_PROG_CC])
-  AC_REQUIRE([PANDORA_PLATFORM])
   CFLAG_VISIBILITY=
   HAVE_VISIBILITY=0
   AS_IF([test -n "$GCC"],[

=== modified file 'tests/lib/server_mgmt/server_management.py'
--- tests/lib/server_mgmt/server_management.py	2011-01-27 20:13:55 +0000
+++ tests/lib/server_mgmt/server_management.py	2011-01-31 22:33:43 +0000
@@ -131,8 +131,11 @@
             while not server.ping(quiet= True) and attempts_remain:
                 time.sleep(1)
                 attempts_remain = attempts_remain - 1
-        if server.status == 1 or server.ping(quiet=True):
+        if server.ping(quiet=True):
             server.stop()
+        else:
+            # make sure the server is indicated as stopped
+            server.status = 0
 
     def stop_servers(self, requester):
         """ Stop all servers running for the requester """

=== modified file 'tests/lib/sys_mgmt/port_management.py'
--- tests/lib/sys_mgmt/port_management.py	2011-01-29 20:26:04 +0000
+++ tests/lib/sys_mgmt/port_management.py	2011-01-31 21:04:48 +0000
@@ -130,9 +130,14 @@
                     if self.system_manager.cur_os in [ 'FreeBSD' 
                                                      , 'Darwin' 
                                                      ]:
-                        used_port = int(entry.split()[3].split('.')[-1].strip())
-                    else:
-                        used_port = int(entry.split()[3].split(':')[-1].strip())
+                        split_token = '.'
+                    else:
+                        split_token = ':'
+                    port_candidate = entry.split()[3].split(split_token)[-1].strip()
+                    if port_candidate.isdigit():
+                        used_port = int(port_candidate)
+                    else:
+                        used_port = None # not a value we can use
                 if port == used_port:
                     if entry.split()[-1] != "TIME_WAIT":
                         return 1

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2011-01-08 10:35:13 +0000
+++ tests/r/show_check.result	2011-01-31 16:31:35 +0000
@@ -502,4 +502,6 @@
 drop table `été`;
 show columns from `#mysql50#????????`;
 Got one of the listed errors
+show innodb status;
+ERROR HY000: Engine status is now stored in the data_dictionary tables, please use these instead.
 End of 5.1 tests

=== modified file 'tests/t/show_check.test'
--- tests/t/show_check.test	2011-01-02 06:09:12 +0000
+++ tests/t/show_check.test	2011-01-31 16:31:35 +0000
@@ -351,4 +351,10 @@
 --error ER_NO_SUCH_TABLE,ER_FILE_NOT_FOUND
 show columns from `#mysql50#????????`;
 
+#
+# Test error output for SHOW engine_name STATUS
+#
+--error ER_USE_DATA_DICTIONARY
+show innodb status;
+
 --echo End of 5.1 tests

